<?php
/*
Plugin Name: WPHawy Custom Registration Password
Description: Let the user to choose his password in registration form.
Author: Aboelabbas
Author URI: http://www.wphawy.com/
Version: 1.0
*/

class WPHawy_CRP {

	private static $_instance = null;
	
	/*
	* Dummy Constructor.
	*/
	private function __construct() {}
	
	/*
	* The true Constructor.
	*/
	public static function init() {
	
		if ( null == self::$_instance ) {
		
			self::$_instance = new self;
			
			self::$_instance->hooksInit();
			
		}
		
		return self::$_instance;
	}
	
	/*
	* Initiate needed hooks.
	*/
	private function hooksInit() {
	
		add_action( 'register_form', array( $this, 'addHTML' ) );
		add_action( 'login_enqueue_scripts', array( $this, 'enqueue' ) );
		
		add_filter( 'registration_errors', array( $this, 'validatePass' ), 10, 3 );
		add_filter( 'random_password', array( $this, 'setRandomPass' ) );
		add_filter( 'shake_error_codes', array( $this, 'shakeErrors' ) );
		add_filter( 'gettext', array( $this, 'successMsg' ) );
	}
	
	/*
	* Add HTML to the register form.
	*/
	public function addHTML() { ?>
		<p>
			<label for="pass1"><?php _e('Password') ?><br />
			<input type="password" name="pass1" id="pass1" class="input" size="20" value="" autocomplete="off" /></label>
		</p>
		<p>
			<label for="pass2"><?php _e('Confirm new password') ?><br />
			<input type="password" name="pass2" id="pass2" class="input" size="20" value="" autocomplete="off" /></label>
		</p>
		<p id="pass-strength-result" style="display: block;" class=""><?php _e('Strength indicator'); ?></p>
		<p class="description indicator-hint"><?php _e('Hint: The password should be at least seven characters long. To make it stronger, use upper and lower case letters, numbers and symbols like ! " ? $ % ^ &amp; ).'); ?></p>
		<br class="clear" />
	<?php }
	

	/*
	* Add required scripts and CSS to the login header.
	*/

	public function enqueue() {
		
		wp_enqueue_script( 'user-profile' );
		
		echo '<style>
		#reg_passmail{ display: none; }
		.login #login form #pass-strength-result {
			width: auto;
			display:block;
			float: none;
			clear: both;
		}
		@media screen and (min-width:800px) {
			
			#login {
				width: 600px;
			}
			#login form p {
				float: left;
				margin: 0 0 0 15px;
				width: 261px;
			}
			#login form p.indicator-hint,#login form p.submit,
			.rtl #login form p.indicator-hint,.rtl #login form p.submit {
				float: none;
				clear: both;
				width: auto;
			}
			.rtl #login form p {
				float: right;
				margin: 0 15px 0 0;
			}
			
			#login form .button {
				width: 100%;
			}
		}
		</style>';
	}


	/**
	* Make sure the password field is required and matches the confirmation field.
	*/

	public function  validatePass( $errors, $login, $email ) {

		
		$pass1  = ( isset( $_POST['pass1'] ) ) ? $_POST['pass1'] : null;
		$pass2  = ( isset( $_POST['pass2'] ) ) ? $_POST['pass2'] : null;
		
		if ( ! $pass1 ) {
			
			$errors->add( 'empty_password', __( '<strong>ERROR</strong>: The password field is empty.' ) );
			
		}
		
		if ( $pass1 != $pass2 ) {
		
			$errors->add( 'password_reset_mismatch', __( 'The passwords do not match.' ) );
			
		}
		
		return $errors;

	}

	/*
	* Return the entered password.
	*/
	public function setRandomPass( $password ) {
		
		return ( isset( $_POST['pass1'] ) ) ? $_POST['pass1'] : null;
		
	}

	
	/*
	* Add new errors codes to shake_error_codes array.
	*/
	public function shakeErrors( $shake_error_codes ) {
		
		$shake_error_codes[] = 'password_reset_mismatch';
		$shake_error_codes[] = 'username_exists';
		$shake_error_codes[] = 'email_exists';
		
		return $shake_error_codes;
	}
	
	/*
	* change success message.
	*/
	
	public function successMsg( $str ) {
		
		$str = str_replace( array( 'Registration complete. Please check your e-mail.', 'تمّ التسجيل بنجاح. يرجى مراجعة بريدك الإلكتروني.' ),
		array( 'Registration complete. You can login by username and password.', 'تم التسجيل بنجاح يمكنك الدخول باسم المستخدم وكلمة المرور.' ), 
		
		$str );
		
		return $str;
	}

}

$WPHawy_CRP = WPHawy_CRP::init();

if ( ! function_exists( 'wp_new_user_notification' ) ) :
/*
* Unplug the default wp_new_user_notification() to prevent registration password email from being sent.
*/
function wp_new_user_notification( $user_id, $plaintext_pass = '' ) {
	$user = get_userdata( $user_id );

	// The blogname option is escaped with esc_html on the way into the database in sanitize_option
	// we want to reverse this for the plain text arena of emails.
	$blogname = wp_specialchars_decode( get_option( 'blogname' ), ENT_QUOTES );

	$message  = sprintf( __( 'New user registration on your site %s:' ), $blogname ) . "\r\n\r\n";
	$message .= sprintf( __('Username: %s' ), $user->user_login) . "\r\n\r\n";
	$message .= sprintf( __('E-mail: %s' ), $user->user_email) . "\r\n";

	@wp_mail( get_option( 'admin_email' ), sprintf( __('[%s] New User Registration'), $blogname ), $message );

}

endif;